import { useBlock } from "../../../composables/base/useBlock.js";
import { BlockProps } from "../../../composables/base/useBaseProps.js";
import { NavTabProps, useNavTab } from "../../../composables/bootstrap/useNavTab.js";
import {
  CurrentProps,
  useItemsCurrent
} from "../../../composables/bootstrap/useItemsCurrent.js";
import { hProps, addProp } from "../../../composables/utils/useProps.js";
import { IDProps, useID } from "../../../composables/attributes/useID.js";
import { defineComponent, h, ref, computed } from "#imports";
export default defineComponent({
  name: "NavbarNav",
  props: {
    ...BlockProps,
    ...NavTabProps,
    ...CurrentProps,
    ...IDProps,
    scroll: {
      type: Boolean,
      default: false
    },
    scrollHeight: {
      type: String,
      default: void 0
    },
    tag: {
      type: String,
      default: "div"
    }
  },
  setup(props, context) {
    const elementRef = ref();
    const block = useBlock(props);
    const id = useID(props, "navbar-nav");
    const itemsCurrent = useItemsCurrent(props, context, elementRef, "nav");
    const navTab = useNavTab(props);
    const current = {
      class: computed(() => {
        return {
          "navbar-nav": true,
          "navbar-nav-scroll": props.scroll
        };
      }),
      style: computed(() => {
        return {
          ...addProp(props.scrollHeight, "--bs-scroll-height", `${props.scrollHeight}`)
        };
      }),
      ref: elementRef
    };
    return () => h(
      props.tag,
      hProps(current, itemsCurrent, navTab, block, id),
      context.slots
    );
  }
});
